.. image:: https://readthedocs.org/projects/gocd-tools/badge/?version=latest
    :target: https://gocd-tools.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

==========
gocd-tools
==========

A tool for automating the configuration of a `GoCD <https://www.gocd.org>`_ server.
It achieves this by utilizing the published `GoCD API <https://api.gocd.org/current/#introduction>`_ specification.

---------------
Getting Started
---------------

Before the ``gocd-tool`` can be used, it has to be built and installed.
The easiest way to accomplish this is to use the PyPI installer::

    pip install gocd-tools


------
How-to
------

For additional information about how to use the tool and how it should be
configured and etc. Please see the `Documentation <https://gocd-tools.readthedocs.io/en/latest/>`_.